==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/BuildPostCommitSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface BuildPostCommitSpecFluent<A extends BuildPostCommitSpecFluent<A>> extends Fluent<A> {


    public A addToArgs(int index,String item);
    public A setToArgs(int index,String item);
    public A addToArgs(String... items);
    public A addAllToArgs(Collection<String> items);
    public A removeFromArgs(String... items);
    public A removeAllFromArgs(Collection<String> items);
    public List<String> getArgs();
    public String getArg(int index);
    public String getFirstArg();
    public String getLastArg();
    public String getMatchingArg(Predicate<String> predicate);
    public Boolean hasMatchingArg(Predicate<String> predicate);
    public A withArgs(List<String> args);
    public A withArgs(String... args);
    public Boolean hasArgs();
    public A addNewArg(String arg1);
    public A addNewArg(StringBuilder arg1);
    public A addNewArg(StringBuffer arg1);
    public A addToCommand(int index,String item);
    public A setToCommand(int index,String item);
    public A addToCommand(String... items);
    public A addAllToCommand(Collection<String> items);
    public A removeFromCommand(String... items);
    public A removeAllFromCommand(Collection<String> items);
    public List<String> getCommand();
    public String getCommand(int index);
    public String getFirstCommand();
    public String getLastCommand();
    public String getMatchingCommand(Predicate<String> predicate);
    public Boolean hasMatchingCommand(Predicate<String> predicate);
    public A withCommand(List<String> command);
    public A withCommand(String... command);
    public Boolean hasCommand();
    public A addNewCommand(String arg1);
    public A addNewCommand(StringBuilder arg1);
    public A addNewCommand(StringBuffer arg1);
    public String getScript();
    public A withScript(String script);
    public Boolean hasScript();
    public A withNewScript(String arg1);
    public A withNewScript(StringBuilder arg1);
    public A withNewScript(StringBuffer arg1);
}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/BuildPostCommitSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface BuildPostCommitSpecFluent<A extends BuildPostCommitSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToArgs(int index,String item);
    public A setToArgs(int index,String item);
    public A addToArgs(String... items);
    public A addAllToArgs(Collection<String> items);
    public A removeFromArgs(String... items);
    public A removeAllFromArgs(Collection<String> items);
    public List<String> getArgs();
    public String getArg(int index);
    public String getFirstArg();
    public String getLastArg();
    public String getMatchingArg(Predicate<String> predicate);
    public Boolean hasMatchingArg(Predicate<String> predicate);
    public A withArgs(List<String> args);
    public A withArgs(String... args);
    public Boolean hasArgs();
    public A addNewArg(StringBuilder arg1);
    public A addNewArg(int[] arg1,int arg2,int arg3);
    public A addNewArg(char[] arg1);
    public A addNewArg(StringBuffer arg1);
    public A addNewArg(byte[] arg1,int arg2);
    public A addNewArg(byte[] arg1);
    public A addNewArg(char[] arg1,int arg2,int arg3);
    public A addNewArg(byte[] arg1,int arg2,int arg3);
    public A addNewArg(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewArg(String arg1);
    public A addToCommand(int index,String item);
    public A setToCommand(int index,String item);
    public A addToCommand(String... items);
    public A addAllToCommand(Collection<String> items);
    public A removeFromCommand(String... items);
    public A removeAllFromCommand(Collection<String> items);
    public List<String> getCommand();
    public String getCommand(int index);
    public String getFirstCommand();
    public String getLastCommand();
    public String getMatchingCommand(Predicate<String> predicate);
    public Boolean hasMatchingCommand(Predicate<String> predicate);
    public A withCommand(List<String> command);
    public A withCommand(String... command);
    public Boolean hasCommand();
    public A addNewCommand(StringBuilder arg1);
    public A addNewCommand(int[] arg1,int arg2,int arg3);
    public A addNewCommand(char[] arg1);
    public A addNewCommand(StringBuffer arg1);
    public A addNewCommand(byte[] arg1,int arg2);
    public A addNewCommand(byte[] arg1);
    public A addNewCommand(char[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3);
    public A addNewCommand(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewCommand(String arg1);
    public String getScript();
    public A withScript(String script);
    public Boolean hasScript();
    public A withNewScript(StringBuilder arg1);
    public A withNewScript(int[] arg1,int arg2,int arg3);
    public A withNewScript(char[] arg1);
    public A withNewScript(StringBuffer arg1);
    public A withNewScript(byte[] arg1,int arg2);
    public A withNewScript(byte[] arg1);
    public A withNewScript(char[] arg1,int arg2,int arg3);
    public A withNewScript(byte[] arg1,int arg2,int arg3);
    public A withNewScript(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewScript(String arg1);
}
